==> igniteui-webcomponents-core-3.2.2.tgz: package/esm5/lib/StandardDeviationIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { StandardDeviationIndicatorDescription } from "./StandardDeviationIndicatorDescription";
/**
 * @hidden
 */
var StandardDeviationIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(StandardDeviationIndicatorDescriptionMetadata, _super);
    function StandardDeviationIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StandardDeviationIndicatorDescriptionMetadata.b = function (a) {
        if (StandardDeviationIndicatorDescriptionMetadata.a == null) {
            StandardDeviationIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            StandardDeviationIndicatorDescriptionMetadata.c(StandardDeviationIndicatorDescriptionMetadata.a);
        }
        if (a.g(StandardDeviationIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.s(StandardDeviationIndicatorDescriptionMetadata.a);
    };
    StandardDeviationIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("Period", "Number:int");
    };
    StandardDeviationIndicatorDescriptionMetadata.d = function (a) {
        StandardDeviationIndicatorDescriptionMetadata.b(a);
        a.u("StandardDeviationIndicator", function () { return new StandardDeviationIndicatorDescription(); });
        a.t("StandardDeviationIndicator", StandardDeviationIndicatorDescriptionMetadata.a);
    };
    StandardDeviationIndicatorDescriptionMetadata.$t = markType(StandardDeviationIndicatorDescriptionMetadata, 'StandardDeviationIndicatorDescriptionMetadata');
    StandardDeviationIndicatorDescriptionMetadata.a = null;
    return StandardDeviationIndicatorDescriptionMetadata;
}(Base));
export { StandardDeviationIndicatorDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/StandardDeviationIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { StandardDeviationIndicatorDescription } from "./StandardDeviationIndicatorDescription";
/**
 * @hidden
 */
var StandardDeviationIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(StandardDeviationIndicatorDescriptionMetadata, _super);
    function StandardDeviationIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StandardDeviationIndicatorDescriptionMetadata.b = function (a) {
        if (StandardDeviationIndicatorDescriptionMetadata.a == null) {
            StandardDeviationIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            StandardDeviationIndicatorDescriptionMetadata.c(StandardDeviationIndicatorDescriptionMetadata.a);
        }
        if (a.j(StandardDeviationIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.y(StandardDeviationIndicatorDescriptionMetadata.a);
    };
    StandardDeviationIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("Period", "Number:int");
    };
    StandardDeviationIndicatorDescriptionMetadata.d = function (a) {
        StandardDeviationIndicatorDescriptionMetadata.b(a);
        a.aa("StandardDeviationIndicator", function () { return new StandardDeviationIndicatorDescription(); });
        a.z("StandardDeviationIndicator", StandardDeviationIndicatorDescriptionMetadata.a);
    };
    StandardDeviationIndicatorDescriptionMetadata.$t = markType(StandardDeviationIndicatorDescriptionMetadata, 'StandardDeviationIndicatorDescriptionMetadata');
    StandardDeviationIndicatorDescriptionMetadata.a = null;
    return StandardDeviationIndicatorDescriptionMetadata;
}(Base));
export { StandardDeviationIndicatorDescriptionMetadata };
